package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`*``!````\!D!`#0```"$D0````0`!30`(``)
M`"@`'``;``$``'#H@P``Z(,!`.B#`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!`````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0#T@P``](,```4```````$`
M`0```)B-``"8C0(`F(T"`'@"``"D$@``!@```````0`"````O(T``+R-`@"\
MC0(`*`$``"@!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DF(T`
M`)B-`@"8C0(`:`(``&@"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````,````"``````````0````4
M`````P```$=.50`'QE\OV4)+>@?$87UY=(%T3UKJ$F$````$````(`````H`
M``"@$@```D01(``"0`!6`'`8P@@`,`@`$!$``!`"`"@`````````2`(@"@`*
M``2$`JA`"`5@:0"$"3Y"/)<``0`()%B`!(E@#)-X"4):`$``0``!`$()`$"`
MC,"$```0D!"#"0`(`1"`@4!`P@F`+$"8`D$`(,`@!`D`D``D#I=V0`0`````
M````!0````8````(``````````````````````````D````+````#`````X`
M```/````$````!(````5`````````````````````````!<````:````&P``
M```````?````(````"$`````````(@```",````G`````````"D`````````
M`````"H````K````+````"T`````````,0```#(````V````-P``````````
M````.````#L````\`````````#T````^````0````$(```!%`````````$<`
M``!(````20```$H`````````2P``````````````````````````````````
M`$P```!-`````````$\`````````40```%,```!5````````````````````
M`````%8```!:`````````%L`````````70``````````````7P``````````
M````80```&,```!E````9@```&D```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->_!*:W94/)3-/PRO]R/.((D'<-,@=+`"U634?&:OS&8N3CWVV_<`
M7@:DA_\!KS3HSDJN_\[>1RWAIP(*XT?&`<8.X#T^?I9\[#^0`FUSA<7%B060
M89CO$@$C^:2=NY,<0D75[%#N$>.&^9R!?>T1#[J5DQQ;FCL/04V=?*?=HVM9
M[Y=Y.?*+'`P4XIX$,J6%H@+V&=O-XY[[H6Q@ZM/O#L@Y0!\R8MOMN8WQ#C^>
M0D3I^\/"2B)]_PJ*$%?MWI,<K4OCP-EQ6!PKT.$B&I_6O2T.L7-8.T`?P^4_
M+)@BU&BZXY)\(?_D#HJ8W<)O>FGZDZT$8C?C\,%#\N_(WX4@3U>DFY;%N9Q`
M4!M]7S&X@@V^VE<;LP&+;[S02WUW;^-P:@E#UI\BQZ@A8F0'?JF<FV+0^H+L
M+/:+:W^:?(?PEGSN"U'Y\]O3'9!U@@U#9DL0/*TY#1?J6O&FFY,<H^#[2>)7
MQ!A7DEI2_=+O#V[%WQ]\D!#I+=_^2"[%F[;)U;)Q````````````````````
M`!$``````````````"`````M```````````````@````/```````````````
M(````%8#`````````````!(````B`@`````````````2````MP(`````````
M````$@```)0"`````````````!(````^!````)`"```````@`!<`DP$`````
M````````$@```(T"`````````````!(```"#`0``)!4!```````2````S@,`
M`!"0`@``````$``8`%`"`````````````!(```!R`@`````````````2````
M?@0```R0`@`$````$0`7`/H"`````````````!(```#C!```J#\!`'`#```2
M``T`(P0``&0R`0`4`0``$@`-`%T#`````````````!(```!8`@``````````
M```2````"P,`````````````$@````L$```\H`(``````!``&`#N`P``````
M```````2````+P0``&PV`0`\"0``$@`-`%@$``!L+P$`R````!(`#0`6!```
M/#(!`"@````2``T`?P(`````````````$@```$L"`````````````!(```!<
M`0`````````````2````YP(`````````````$@```'`#```0D`(`!````"$`
M&``*`@`````````````2````$0(`````````````$@```*D"````````````
M`!(````#!```$)`"```````0`!<`Q`(`````````````$@```',```!,%P$`
M`````!(```"'`@`````````````2````*`,`````````````$@````0"````
M`````````!(````J`@`````````````2````<0,``!"0`@`$````(0`8`(T$
M```\H`(``````!``&``$`P``()`"``0````1`!@`K0,```1$`0`$````$@`-
M`&<!`````````````!(```!#`0`````````````2````;@0``*1#`0!@````
M$@`-`,,$``"D-0$`R````!(`#0"W`P``"$0!```````2``X`80(`````````
M````$@```$($``#P&0$``````!(`#0"P!```F!0!```````2``L`DP``````
M````````$@```)\``````````````!(```#9`@`````````````2````XP``
M`!R0`@`!````$0`8`*("`````````````!(```!)!```$$0!``0````1``\`
MH@0``!"0`@``````$``8`"\#`````````````!(```!'`P`````````````2
M````5@``````````````$@```/```````````````!(```"N!```Y"X!`#0`
M```2``T`#`$`````````````$@```(@$```\H`(``````!``&`"V!```.#`!
M``0"```2``T`M```````````````$@```#D"`````````````!(```#P`0``
M```````````2````=0$`````````````$@```,(``````````````!(```#4
M```````````````2`````0$``!B0`@`$````$0`8`&\#```0D`(`!````!$`
M&``U`0`````````````2````L`(`````````````$@````H$```\H`(`````
M`!``&`#5!```$#4!`'P````2``T`A```````````````$@```/("````````
M`````!(````\!````)`"```````0`!<`.0,`````````````$@```(T#``"@
MC0(`!````!$`%`#<`P``C#4!`!@````2``T`L0$`````````````$@```)X!
M`````````````!(```!J`P``T!<!`"`"```2``T`$0$`````````````$@``
M`!(#`````````````!(```"\`0``J(T"`!,````1`!0`T@(`````````````
M$@```+X"`````````````!(```"J`0`````````````2````3P,`````````
M````$@```)L"`````````````!(```"5!```>#,!`)@!```2``T`&P,`````
M````````$@```!8!`````````````!(```!Y`@`````````````2````]P,`
M`!A#`0!X````$@`-`&0``````````````!(```!3`0`````````````2````
MO0,``#0P`0`$````$@`-`"(!``#4%@$``````!(`````;&EB<&5R;"YS;RXU
M+C(X`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?
M7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!0
M97)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T
M`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M
M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?
M;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?
M9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`
M4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L
M7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L:6)D
M;"YS;RXR`&QI8FTN<V\N-@!L:6)P=&AR96%D+G-O+C``<'1H<F5A9%]G971S
M<&5C:69I8P!C;&]S90!O<&5N-C0`7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T
M`')E860`;&EB8RYS;RXV`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M
M<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L
M;&]C`&%B;W)T`&UE;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`
M;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T
M<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R
M`&=E='5I9`!R96%D;&EN:P!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V
M-`!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V5N=FER;VX`;&0M;&EN=7@M87)M:&8N<V\N,P!?7W-T
M86-K7V-H:U]G=6%R9`!L:6)C<GEP="YS;RXQ`%]?;&EB8U]C<W5?9FEN:0!P
M87)?8W5R<F5N=%]E>&5C`%]?8G-S7W-T87)T7U\`9V5T7W5S97)N86UE7V9R
M;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7V5D871A`%]?8G-S7V5N9%]?`'!A
M<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T
M87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI
M8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]E;F0`7U]E;F1?7P!P87)?:6YI=%]E
M;G8`7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P
M7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`
M1TQ)0D-?,BXT``````````````(``P`"``(``0````(````!``(``@`!``(`
M`0`!``(``@`"``$``@`!``$``0`"``(````"``(``P`#``(``0`"`````@`"
M``,``P`"``$``@`!```````!``$``0`"``$``0```````@````(``0`!``(`
M`@```````0````$``0````(``P````````````(````"``$``0````(``0`"
M``0``0```````0`"``(````"``(``@`"``(``0`"`````@`!```````!````
M```!``$`>0,``!`````@````%&EI#0``!`#Y!`````````$``0#@`0``$```
M`"`````4:6D-```#`/D$`````````0`!`"\"```0`````````!1I:0T```(`
M^00```````#XCP(`%0(``*"-`@`450``J(T"`!1<```0D`(`%$P``!B0`@`4
M2P``')`"`!0Y```@D`(`%"P``/".`@`6!@``](X"`!8$``#XC@(`%A<``/R.
M`@`6*0```(\"`!85```$CP(`%CX```B/`@`66@``#(\"`!9%```0CP(`%ET`
M`!2/`@`6"P``&(\"`!9>```<CP(`%E$``""/`@`60@``)(\"`!8X```HCP(`
M%F$``"R/`@`6,P``,(\"`!9&```TCP(`%@X``#B/`@`6&P``/(\"`!8N``!`
MCP(`%DT``$2/`@`66P``2(\"`!9C``!,CP(`%DD``%"/`@`65P``5(\"`!8%
M``!8CP(`%E@``%R/`@`64@``8(\"`!8@``!DCP(`%E\``&B/`@`6$P``;(\"
M`!8O``!PCP(`%@(``'2/`@`6!P``>(\"`!8<``!\CP(`%B(``("/`@`69P``
MA(\"`!8G``"(CP(`%C8``(R/`@`6(0``D(\"`!94``"4CP(`%C<``)B/`@`6
M'0``G(\"`!9E``"@CP(`%DX``*2/`@`6:@``J(\"`!8_``"LCP(`%F0``+"/
M`@`6"0``M(\"`!8D``"XCP(`%D```+R/`@`6"@``P(\"`!9@``#$CP(`%CH`
M`,B/`@`62```S(\"`!8E``#0CP(`%CT``-2/`@`62@``V(\"`!9H``#<CP(`
M%A```."/`@`6#0``Y(\"`!8F``#HCP(`%B@``.R/`@`6'@``\(\"`!84``#T
MCP(`%D<```A`+>EB`0#K"("]Z`3@+>4$X)_E#N"/X`CPON4P>@$``,:/XA?*
MC.(P^KSE`,:/XA?*C.(H^KSE`,:/XA?*C.(@^KSE`,:/XA?*C.(8^KSE`,:/
MXA?*C.(0^KSE`,:/XA?*C.((^KSE`,:/XA?*C.(`^KSE`,:/XA?*C.+X^;SE
M`,:/XA?*C.+P^;SE`,:/XA?*C.+H^;SE`,:/XA?*C.+@^;SE`,:/XA?*C.+8
M^;SE`,:/XA?*C.+0^;SE`,:/XA?*C.+(^;SE`,:/XA?*C.+`^;SE`,:/XA?*
MC.*X^;SE`,:/XA?*C.*P^;SE`,:/XA?*C.*H^;SE`,:/XA?*C.*@^;SE`,:/
MXA?*C.*8^;SE`,:/XA?*C.*0^;SE`,:/XA?*C.*(^;SE`,:/XA?*C.*`^;SE
M`,:/XA?*C.)X^;SE`,:/XA?*C.)P^;SE`,:/XA?*C.)H^;SE`,:/XA?*C.)@
M^;SE`,:/XA?*C.)8^;SE`,:/XA?*C.)0^;SE`,:/XA?*C.)(^;SE`,:/XA?*
MC.)`^;SE`,:/XA?*C.(X^;SE`,:/XA?*C.(P^;SE`,:/XA?*C.(H^;SE`,:/
MXA?*C.(@^;SE`,:/XA?*C.(8^;SE`,:/XA?*C.(0^;SE`,:/XA?*C.((^;SE
M`,:/XA?*C.(`^;SE`,:/XA?*C.+X^+SE`,:/XA?*C.+P^+SE`,:/XA?*C.+H
M^+SE`,:/XA?*C.+@^+SE`,:/XA?*C.+8^+SE`,:/XA?*C.+0^+SE`,:/XA?*
MC.+(^+SE`,:/XA?*C.+`^+SE`,:/XA?*C.*X^+SE`,:/XA?*C.*P^+SE`,:/
MXA?*C.*H^+SE`,:/XA?*C.*@^+SE`,:/XA?*C.*8^+SE`,:/XA?*C.*0^+SE
M`,:/XA?*C.*(^+SE`,:/XA?*C.*`^+SE`,:/XA?*C.)X^+SE`,:/XA?*C.)P
M^+SE`,:/XA?*C.)H^+SE`,:/XA?*C.)@^+SE`,:/XA?*C.)8^+SE`,:/XA?*
MC.)0^+SE`,:/XA?*C.)(^+SE`,:/XA?*C.)`^+SE`,:/XA?*C.(X^+SE`,:/
MXA?*C.(P^+SE`,:/XA?*C.(H^+SE<$`MZ2#03>+849_E%`"-Y1`0C>4`,)7E
M#""-Y1`0C>(,((WB%`"-XAPPC>69___KM"&?Y;0!G^4"$*#AWPH`ZZPQG^4`
M8-/E``!6XZ1!GQ4)```::___ZYPAG^4``%#C$`""Y5P```J(09_E/O__ZP``
ME.7>___K<6?`Y0``E.7;___K`""@X0``E.7&,]+E`C"#X\8SPN75___K%#"=
MY04P@^('`7/CQB/0Y0$@@N/&(\#E10``B@,!H.%7___K."&?Y1`PG>4L09_E
M!!"2Y0#`D^44()WE`0!2XP3@0\(($(#E&!&?Y0#`@.44P9_E#!"`Y000H.,$
M$(3E!,"`Y0@`A.4"X8[`#!"`P@,``-H$P+/E`P!>X03`H>7[__\:#<&"X@`0
MH.,`$(WE`#"@X0P1@.<#((+BS!"?Y1``E.5X___K`&!0XA````H0`)3E'?__
MZQ@0C>*P`)_EX@,`ZP``4.,-```*$`"4Y0'__^MF___K'""=Y0`PE>4&`*#A
M`P!2X18``!H@T(WB<("]Z!``E.6!___K`&"@X>K__^H,`)3E``!0XP$```IE
M"@#K[/__ZA@0C>)4`)_ER@,`ZP``4.,,`(3EYO__"O;__^I`$)_E0`"?Y3W_
M_^L!`*#C)O__Z^S^_^N@C0(`U!8!`$P7`0`<D`(`&)`"`"B0`@`(D`(`B$<!
M`(1'`0`8+P$`/$4!`-A$`0"HC0(`O$8!``"PH.,`X*#C!!"=Y`T@H.$$("WE
M!``MY1#`G^4$P"WE#`"?Y0PPG^4`___K7/__ZP1$`0#0%P$`I$,!`!0PG^44
M()_E`S"/X`(@D^<``%+C'O\O`?O^_^JH=`$`%`$``!@`G^48,)_E``!3X1[_
M+P$0,)_E``!3XQ[_+P$3_R_A$)`"`!"0`@``````)`"?Y200G^4`$$'@01&@
MX:$?@>#!$+#A'O\O`1`PG^4``%/C'O\O`1/_+^$0D`(`$)`"```````00"WI
M&$"?Y0`PU.4``%/C$("]&.#__^L!,*#C`##$Y1"`O>@DD`(`YO__ZL`]G^7P
M3RWII=]-X@`PD^5`$(#B@%"`X@@@C>(`0*#CC#*-Y03`$>4(X!'E"!"!XBPT
MH.'_/`/B+#R#X0QDH.$,/(/A_\@&X@PP@^$!`%7A/L^_Y@1`@N4,0(+E"#""
MY0#`@N40((+B[?__&@+LC>(-$*#A`$"@XP'`H.$(8+'E2%"<Y7`PG.48@)SE
M=""<Y4QPG.4%,"/@'%"<Y0@P(^`$P)'E!R`BX`8P(^`%("+@#"`BX*//H.&"
MP(SA@S",X0X`4>&$0('E@#"!Y>G__QH(@)#E#,"0Y0"@D.4H(:#A#"^"X1"0
MD.4([X+A!!"0Y1@@D.70/)_E"%"=Y:K-H.$"0"G@(""0Y0-0E>"!PHSA`E"5
MX(K"C.$%P)S@&%"0Y0X@*>`(0`3@!4`DX`H@`N`08)WE*E&@X0%?A>$)$"+@
M&""0Y03`G.`#8);@"E^%X0(@EN`88)WE!4`NX`$@DN#L':#A`2"2X`Q`!.`#
M$);@;,&@X0Y`).`@<)WE"1"1X.)MH.$$$)'@#$`EX`80D>`"0`3@`V"7X&(A
MH.$.X);@*'"=Y05`).#A;:#A!$">X`+@+.`&0)3@`>`.X`-@E^!A$:#A#.`N
MX#!PG>4%4);@#E"5X.1MH.$!X"+@!E"5X`3@#N`#8)?@9$&@X0S`EN`X<)WE
M`N`NX.5MH.$.X)S@!,`AX`;@GN`%P`S@`V"7X&51H.$"();@0'"=Y0'`+.#N
M;:#A#,"2X`4@).`&P)S@#B`"X`-@E^!NX:#A!"`BX$APG>4!$);@`A"1X.QM
MH.$.("7@!A"1X`P@`N`#8)?@;,&@X04@(N!0<)WE!$"6X`)`E.#A;:#A#"`N
MX`9`E.`!(`+@`V"7X&$1H.$.("+@6'"=Y050EN`"4)7@Y&V@X0$@+.`&4)7@
M!"`"X`-@E^!D0:#A#"`BX&!PG>4.X);@`N">X.5MH.$$("'@!N">X`4@`N`#
M8)?@95&@X0$@(N!H<)WE#,"6X`+`G.#N;:#A!2`DX`;`G.`.(`+@`V"7X&[A
MH.$$("+@<'"=Y0$0EN`"$)'@[&V@X0X@)>`&$)'@#"`"X`-@E^!LP:#A!2`B
MX'APG>4$0);@`D"4X.%MH.$,("[@!D"4X`$@`N`#8)?@81&@X0X@(N"`<)WE
M!5"6X`)0E>#D;:#A`2`LX`90E>`$(`+@`V"7X&1!H.$,("+@B'"=Y0[@EN`"
MX)[@Y6V@X00@(>`&X)[@!2`"X`-@E^!E4:#A`2`BX)!PG>4,P);@`L"<X.YM
MH.$%("3@!L"<X`X@`N`#8)?@;N&@X00@(N"8<)WE`1"6X`(0D>#L;:#A#B`E
MX`80D>`,(`+@`V"7X&S!H.$$0);@H'"=Y04@(N#A;:#A`B"4X`Q`+N`&()+@
M`4`$X`,PE^`.0"3@J'"=Y050D^"D.9_E!%"5X&%!H.'B':#A`5"5X`1@+.`#
M$)?@`F`FX+!PG>4.$)'@!A"1X&+AH.'E+:#A`A"1X`Y@).`#()?@!6`FX+AP
MG>4,()+@!B"2X&7!H.'A7:#A!2"2X`Q@+N`#4)?@P+"=Y0%@)N`$4)7@81&@
MX>)-H.$&4)7@!%"5X`%P+.`#0)O@#N"4X`)@)^#(0)WE8B&@X09@GN#E[:#A
M#F"6X`)P(>`#X)3@#,">X`5`)^#0L)WE9>&@X01`G.#FS:#A#$"4X`YP(N`#
MP)O@`1"<X`90)^#8L)WE9L&@X050D>#D':#A`5"5X`QP+N`#$)O@`B"1X`1@
M)^#@L)WE9!&@X09@DN#E+:#A`F"6X`%P+.`#()O@#N"2X`5`)^#HL)WE92&@
MX01`GN#F[:#A#D"4X`)P(>`#X)O@#,">X`90)^#PL)WE9N&@X050G.#DS:#A
M#%"5X`YP(N`#P)O@`1"<X`1@)^#XL)WE9,&@X09@D>#E':#A`6"6X`QP+N`#
M$)O@`B"1X`5`)^``<9WE91&@X01`DN#F+:#A`D"4X`-0E^`!("S@!B`BX`[@
ME>`(49WE`N">X&8AH.'D;:#A!N">X`)@(>`#4)7@!&`FX`S`E>`049WE9$&@
MX0;`G.#N;:#A!L"<X`1@(N`#4)7@#F`FX!AQG>4!$)7@;N&@X>Q=H.$&$)'@
M!1"1X`Y@).`#4)?@#&`FX`(@E>`@49WE;,&@X08@DN#A;:#A!B"2X`Q@+N`#
M4)7@`6`FX"AQG>4$0)7@81&@X>)=H.$&0)3@!4"4X`%@+.`#4)?@`F`FX`[@
ME>`P49WE8B&@X0;@GN#D;:#A!N">X`)@(>`#4)7@!&`FX#AQG>4,P)7@9$&@
MX>Y=H.$&P)S@!<"<X`1@(N`#4)?@#F`FX`$0E>!`49WE;N&@X080D>#L;:#A
M!A"1X`Y@).`#,)7@#&`FX$AQG>5LP:#A`B"3X-`VG^4,4([A!B"2X.%MH.$&
M()+@#+`.X`-@E^`!4`7@"U"%X6$1H.%0<9WE!$"6X`5`E.`!8(SAXEV@X05`
ME.`"8`;@`5`,X`-PE^!B(:#A#G"7X`5@AN%849WE`K"!X>3MH.$'8);@#F"6
MX`2P"^`"<`'@`^"5X&1!H.$'<(OA#.">X&"QG>4$P(+A#N"7X.9]H.$'X)[@
M!%`"X`.PF^`&P`S@`1";X&9AH.%H<9WE!<",X0'`G.`&4(3A[AV@X0ZP!>`!
MP)S@!E`$X`,0E^!NX:#A!5"+X0(0D>`!$)7@#B"&X>Q=H.$%$)'@#"`"X`Y0
M!N`%((+A<+&=Y7A1G>5LP:#A!%"-Y0.PF^`,4([A!$";X`&P!>`$4)WE!$"2
MX.$MH.$"0)3@81&@X0QP#N`#()7@!W"+X08@DN"`L9WE`6",X01@!N`!4`S@
M`B"7X.1]H.$'()+@!5"&X0.PF^"(89WE#N";X`1@C>4.4)7@XNV@X61!H.$.
M4)7@!."=Y01P@>$"L`?@!&`!X`/@GN!B(:#A!F"+X0S`GN"0X9WE`K"$X0S`
MEN#E;:#A!L"<X`6P"^`"8`3@`^">X`:PB^$!$)[@[&V@X0$0F^!E4:#A!A"1
MX)AAG>4%<(+A#.`'X`6P`N`#<);@;,&@X0M@CN$$0)?@H+&=Y0S@A>$$8);@
MX7V@X0Q`H.$!X`[@!\"6X`1P!>`#8)O@81&@X0(@EN`'X([AJ'&=Y0%@A.$"
MX)[@["V@X0+@GN`!L`3@#&`&X`-PE^!L(:#A!7"7X`O`AN&PL9WE`E"!X>YM
MH.$'P)S@!L"<X`Y0!>`#8)O@`G`!X&[AH.$'<(7AN+&=Y01`EN`.4(+A[&V@
MX01`E^`&0)3@#%`%X`-@F^`.<`+@;,&@X0=PA>'`L9WE`1"6X`Q0CN'D;:#A
M`1"7X`80D>`$4`7@`V";X`QP#N!D0:#A!W"%X<BQG>4"();@!%",X>%MH.$"
M()?@!B"2X`1P#.`#8)O@`5`%X`Y@EN!A$:#AT+&=Y0=0A>$!X(3A!E"5X.)M
MH.$&4)7@`7`$X`-@F^`"X`[@!^".X6(AH.'8L9WE#,"6X`)P@>$,P)[@Y>V@
MX0[`G.`%<`?@`F`!X`/@F^!E4:#A!F"'X03@GN#@<9WE!4""X0[@EN#L;:#A
M!N">X`Q`!.`%8`+@`S"7X`9`A.'H<9WE`1"3X%`SG^5LP:#A[FV@X0$0E.`&
M$)'@#$`EX`-@E^`.0"3@\'&=Y0(@EN`$()+@;F&@X>'MH.$.X)+@!D`LX`,@
ME^`!0"3@^'&=Y050DN!A$:#A[BV@X010E>`"4)7@`4`FX`,@E^`.0"3@`+*=
MY0P@DN!NX:#AY<V@X00@DN`,()+@#G`AX`/`F^`&0)S@!7`GX`ABG>5EP:#A
M!T"4X.)=H.$%0)3@#'`NX`-0EN`!$)7@`F`GX!!2G>5B(:#A!F"1X.0=H.$!
M8);@`G`LX`,0E>`.X)'@!%`GX!BRG>5D$:#A!5">X.;MH.$.4)7@`7`BX`/@
MF^`,P)[@!D`GX""RG>5FX:#A!$"<X.7-H.$,0)3@#G`AX`/`F^`"()S@!6`G
MX"BRG>5EP:#A!F"2X.0MH.$"8);@#'`NX`,@F^`!$)+@!%`GX#"RG>5D(:#A
M!5"1X.8=H.$!4)7@`G`LX`,0F^`.X)'@!D`GX#BRG>5F$:#A!$">X.7MH.$.
M0)3@`7`BX`/@F^`,P)[@!6`GX$"RG>5EX:#A!F"<X.3-H.$,8);@#G`AX`/`
MF^`"()S@!%`GX$BRG>5DP:#A!5"2X.8MH.$"4)7@#'`NX`,@F^`!$)+@!D`G
MX%!RG>5F(:#A!$"1X.4=H.$!0)3@`F`LX`,0E^`%8";@6'*=Y0[@D>`&X)[@
M91&@X>1=H.$%X)[@`6`BX`-0E^`$8";@8'*=Y0S`E>!D0:#A[EV@X0;`G.`%
MP)S@!&`AX`-0E^`.8";@:'*=Y0(@E>!NX:#A[%V@X08@DN`%()+@#F`DX`-0
ME^`,8";@<'*=Y0$0E>`&$)'@;%&@X>+-H.$,$)'@!6`NX`/`E^`"8";@>'*=
MY03`G.`&P)S@8B&@X>%-H.$$0)S@`F`EX`/`E^`!8";@#N"<X(!RG>4&X)[@
M81&@X>1MH.$&X([@`W"7X`$P(N`$,"/@!<"7X`/`G.#N/:#A`\",X`J@G.`8
MP)#E`#"@XP[@F.!D0:#A"4"4X`"@@.4,$)'@(,"0Y0C@@.4$,(#E##"`Y10P
M@.4<,(#E)#"`Y2@PG^4,()+@(""`Y8PBG>4`,)/E$$"`Y0,`4N$8$(#E`0``
M&J7?C>+PC[WH,/O_ZZ"-`@"9>8):H>O9;MR\&X_6P6+*\$<MZ0!P4.(K```*
MN#"?Y0"0D^4``%GC*0``"@`PU^4]4%/B`5"@$P``4^,`4*`#``!5XQ(``!H`
M0)GE``!4XPT```H!@*#A"6"@X04@H.$'$*#A!`"@X9O[_^L``%#C`@``&@4P
MU.<]`%/C"P``"@1`MN4``%3C\___&@0`H.'PA[WH!U"@X0$P]>4``%/C/0!3
M$_O__QH'4$7@Y?__Z@E@1N`!4(7B1F&@X05`A.``8(CE!`"@X?"'O>@'0*#A
M[?__Z@E`H.'K___J$)`"`'!`+>D`0*#A<&"?Y7!0G^4(T$WB`#"6Y00PC>4-
M$*#A!`"@X<'__^L``%#C#```"@`0G>4`()7E`3&"X`0`D^4``%#C`0&"Y_/_
M_PH$,(/B!""3Y0``4N,$((/D^___&NW__^H$()WE`#"6Y0,`4N$!```:"-"-
MXG"`O>C7^O_KH(T"`!"0`@#P3RWI`4"@X0`@T>7P89_E%-!-XCT`4N,!0($"
M`#"6Y0!0H.$$`*#A##"-Y07[_^L($(WB`'"@X04`H.&9___K`(!0XCT```K^
M^O_K!P!0X30``"H(@)WEJ)&?Y0B!H.$`,-7E/0!3X@$`H!,``%/C``"@`P``
M4.,%```*!0"@X0$P\.4``%/C/0!3$_O__QH%`$#@`G"'X@``A^``<)GEUOK_
MZP``4.,(`(?G3P``"@`@F>4($)WE!0"@X0$PT.0!$9+G/0!3XP``4Q,`,,'E
M!@``"@$@@>(!,-#D`A"@X0``4^,]`%,3`3#"Y/G__QH!(*#A/3"@XP`PP>4!
M,-3D``!3XP$PXN7[__\:``"@XPP@G>4`,);E`P!2X3<``!H4T(WB\(^]Z`$P
M2.(!(-3D``!2XP$@X^7[__\:\O__ZL"0G^4`L)GE`*";Y0``6N,H```*"#"@
MX0L@H.$```#J"C"@X000LN4!H(/B``!1X_K__QH#,(/B`Q&@X8@PG^4`()/E
M``!2XQ$``!H!(*#C`0"@X0`@@^68^O_K`#!0X@0PC>41```*"H&@X0L0H.$(
M(*#A2?K_ZP0PG>4`,(GE`2"*X@`0H.,"$8/G"*"-Y:+__^H+`*#A9_K_ZP``
M4.,`,*#A``")Y0J!H!'S__\:``#@X\7__^H($*#CWO__ZE3Z_^N@C0(`$)`"
M`"B0`@#P3RWI?-!-XBA1G^4`8%#B`#"5Y70PC>4"```*`##6Y0``4^,%```:
M=""=Y0`PE>4#`%+A/@``&GS0C>+PC[WH9/K_ZP!P4.+V__\*Z("?Y>B0G^7H
MH)_E!P"@X;3Z_^L``%#C*P``"A-`@.($`*#A"!"@X0GZ_^L``%#C]?__"@D0
MH.$$`*#A!/K_ZP``4./P__\*!@"@X6;Z_^L`L*#A!`"@X6/Z_^L``(O@`@"`
MXD[Z_^L*,*#A`"#@XP$0H.,$0(WE`&"-Y0"PH.%H^O_K"Q"@X0@@C>(#`*#C
MG?K_ZP$`<.,+`*#A`P``"A@PG>4/.@/B`0E3XPL```H7^O_K"P"@X?3Y_^L'
M`*#AB/K_ZP``4./3__\:!P"@X9SZ_^L&`*#A^/G_Z[[__^JS___K\O__Z@/Z
M_^N@C0(`=$0!`'A$`0!\1`$`,$`MZ7303>)L0)_E`!"@X0!0H.$`,)3E#2"@
MX0,`H.-L,(WEA?K_ZP``4.,``*`3!```&A`PG>4/.@/B"@I3XP$)4Q,%```*
M;""=Y0`PE.4#`%+A!P``&G30C>(P@+WH!0"@X0(0H.-3^O_K$`]OX:`"H.'S
M___JX/G_ZZ"-`@#P02WI`=I-XMA0G^4(T$WB`<J-X@`PE>4$P(SB`&"@X0&`
MH.'`()_E!!"-XKP`G^4`,(SEX_G_ZP``4.,@``#:"#"-X@%`0.($((/@H!"?
MY00P4N4`<)'E``!3XQ8``!H``%3C&```"@0@H.$O$*#C!`"-XBWZ_^L``%#C
M$@``"@<`H.%3^O_K!#"@X00@C>(&$*#A-_K_ZP$ZC>($,(/B`""3Y0`PE>4#
M`%+A#```&@':C>((T(WB\(&]Z`!`H.'H___J*#"?Y0!PD^4'`*#A0/K_ZP@@
MH.$&$*#AMOG_Z^S__^JE^?_KH(T"`/\/``"$1`$`&)`"`!PPG^400"WI``"3
MY3/Z_^L0,)_E$""?Y1`0G^400+WHZ?G_ZAB0`@`41`$`)!4!`)1$`0`00"WI
M"-!-XC1`G^4``)3E)?K_Z^S__^L``)3E(OK_ZR`PG^4`(*#C!""-Y0`PC>44
M()_E%!"?Y>[Y_^L(T(WB$("]Z!B0`@"`1P$`J#\!`+!$`0!P0"WI`MI-XJA`
MG^48T$WB`BJ-X@`PE.44((+B`#""Y:SY_^N0()_ED#"?Y00@C>4!$*#CB""?
MY0``C>4,`(WBN?G_ZP$:C>(,`(WB$!"!X@$JH.-[^?_K`%!0X@!@H+,)``"Z
M`0"%XH[Y_^L`8%#B!0``"@$:C>(0$('B!2"@X4GY_^L`,*#C!3#&YP(ZC>(4
M,(/B`""3Y0`PE.4&`*#A`P!2X0(``!H"VHWB&-"-XG"`O>A1^?_KH(T"`-1$
M`0#(1`$``1```,S__^KP3RWI0MU-XM0QG^4$T$WB02V-X@`PD^4\((+B`%"@
MX0%@H.&\`9_E$!"-X@`P@N43_O_K+Q"@XP!`H.$%`*#A??G_ZP``4.,-```*
M!1"@X90!G^5@_O_K!0"@X4$]C>(\,(/B`""3Y70QG^4`,)/E`P!2X5D``!I"
MW8WB!-"-XO"/O>@%`*#A9?G_ZUP1G^4`<*#A!@"@X9?Y_^L`L%#BZ?__"@`P
MV^5$@9_E1*&?Y0``4^-`D9_E,&&?Y0%PA^(Q```*``!4XP0```H+$*#A!`"@
MX>SX_^L``%#C(0``"@L`H.%.^?_K`2!`X@(PB^`"(-OG+P!2XP4``!H`$*#C
M`!##Y0$@<^4!`$#B+P!2X_K__PH``(?@"`!0X<K__\H),*#A`2J@XP$0H.,(
M4(WE!*"-Y0"PC>5\`(WB1_G_ZQ`@C>)\$(WB`P"@XWSY_^L``%#C`P``&B`P
MG>4/.@/B`@E3XQ(```H&$*#A``"@XV'Y_^L``%#C`+"@X;+__PH`,-OE``!3
MX\W__QH``%3C!```"F00G^4$`*#ANOC_ZP``4./O__\*4+"?Y0$`H./7___J
M`1"@XWP`C>)+^?_K``!0X^?__QI\$(WB&`"?Y0'^_^M\`(WBTOC_ZY[__^K3
M^/_KH(T"`-A$`0#D1`$`]$0!`/\/````10$`^$0!`'1$`0``,-#E``!3XQ[_
M+P$!((#B+P!3XP(`H`$!,-+D``!3X_K__QH>_R_A$$`MZ0!`4.(Y```*`##4
MY0``4^,V```*]OC_ZP$`0.(`,(3@`P!4X0L``"H`(-3G+P!2XQ```!H!($/B
M`P``Z@`0TN4!($+B+P!1XPH``!H$`%+A`C"@X?C__QH#`%3A#P``&@`PU.4O
M`%/C(```"I``G^400+WHG_C_Z@$@0^(#``#J`!#2Y0$@0N(O`%'C`P``"@(`
M5.$",*#A^/__.NW__^H!,$/B`P``Z@`0T^4!,$/B+P!1XP(``!H#`%3A`R"@
MX?C__SH$($+@`C""X@$*4^,)``"*`2""X@00H.$!.J#C(`"?Y8#X_^L8`)_E
M$("]Z!0`G^400+WH?OC_Z@``H.,0@+WH`$4!`#R0`@!T1`$`,$`MZ3303>(X
MX9_E","-XC1!G^4/`+[H`%"4Y0\`K.@/`+[H+%"-Y0#@GN4/`*SH&`&?Y;#@
MS.%U_?_K$`&?Y7/]_^L,`9_E<?W_ZP@!G^5O_?_K!`&?Y6W]_^L``9_E:_W_
MZ_P`G^5I_?_K^`"?Y6?]_^OT`)_E9?W_Z_``G^5C_?_K[`"?Y6']_^L$$(WB
MY`"?Y2K]_^L`$%#B`0``"L@`G^5\_?_K!!"-XLP`G^4C_?_K`!!0X@$```K`
M`)_E=?W_ZP00C>*X`)_E'/W_ZP`04.(*```*B`"?Y6[]_^ND$)_E=`"?Y6O]
M_^LL()WE`#"4Y0,`4N$1```:--"-XC"`O>@$$(WB@`"?Y0S]_^L`$%#B`@``
M"DP`G^5>_?_K[O__Z@H@H.-D$)_E&0"-XK;X_^L``%#CZ/__&B,0C>+T___J
M*OC_ZR!$`0"@C0(`!$4!`!!%`0`810$`)$4!`"Q%`0`\10$`V$0!`$A%`0!4
M10$`8$4!`.1$`0!L10$`@$4!`)1%`0"@10$`T$4!`+!%`0#$10$`,$`MZ0S0
M3>)@4)_E8$"?Y0``E>4`,)3E`0!PXP0PC>4%```*!""=Y0`PE.4#`%+A#0``
M&@S0C>(P@+WH#1"@X3``G^78_/_K``!0XP0```H``-#E,`!0XP``4!,!`*`3
M``"@`P``A>7M___J^O?_ZPB0`@"@C0(`2$4!`!!`+>G4]__KS??_ZP``4.,`
M`)`5$("]Z/!`+>D<T$WBJ$"?Y0!0H.$0$(WB`#"4Y9P`G^44,(WEO/S_ZP40
MH.$`8%#B`@``"@`PUN4``%/C!P``&G@`G^4*_?_K%""=Y0`PE.4#`%+A%P``
M&AS0C>+P@+WHK/?_ZP``4./V__\:!0"@X1'X_^L`<*#A!@"@X0[X_^L``(?@
M`@"`XOGW_^LP,)_E`1"@XP0PC>4(8(WE`%"-Y2`PG^4`(.#C`'"@X1'X_^L'
M$*#AX?__ZL/W_^N@C0(`U$4!`/1$`0#X1`$`Y#B?Y?!/+>D`@*#A@=Q-X@<`
MD^B<T$WBH,"-X@Q`@^('`(SH),"#X@\`M.BXX(WBK%"-X@\`KN@#`)3HK#B?
MY0,`CN@'`)SH@<R-X@`PD^64P(SB!P"%Z#@0C>*0")_E`#",Y7G\_^L`0%#B
M`@``"@`PU.4``%/C`@$`&J?__^L`4%#BX@``"@4`H.'7]__K@`"@X0$`@.+"
M]__K`##5Y0``4^,`<*#A"P``"D1HG^4'0*#A`#"-Y00`H.$&,*#A`"#@XP$0
MH./7]__K`3#UY0)`A.(``%/C]?__&K@`G>4``%#C$@``"KQ`C>("``#J!`"4
MY```4.,-```*.!"-XE+\_^L`4%#B^/__"@`PU>4``%/C]?__"GC]_^L``%#C
M\O__"@4`H.%Q]__K`)!0XA\``!H`H*#CH&"-XF8_C>(*,8/@^$`3Y0``5.,7
M```*`##4Y0``4^,4```*`5"*X@61AN`$`*#A9/W_ZP6@H.$``%#C!P``&@1`
MF>0``%3C"@``"@`PU.4``%/C!P``"@%0A>+R___J!`"@X53W_^L``%#CY/__
M"@"0H.$```#J`)"@XPD`H.&,]__K.&>?Y0!`H.$'`*#AB/?_ZP!`A.`!2X3B
M!$"$X@0`H.%Q]__K&#>?Y0`@X.,(,(WE`1"@XPPWG^4,<(WE`)"-Y01@C>4`
M4*#AB/?_ZP4`H.$'':#CCO?_ZP$`<.,#```:?_?_ZP`PD.41`%/CC```&C@@
MC>(%$*#A`P"@X\#W_^L`<%#B$@``"KPFG^4`4(WE`1"@XP``DN4`,)CEK":?
MY8WW_^L`0*#C@3R-XI0P@^(`()/E>#:?Y00`H.$`,)/E`P!2X8T!`!J!W(WB
MG-"-XO"/O>A(,)WE#SH#X@$)4^/H__\:4)"=Y?3V_^L``%GAY/__&D@PG>6#
M.Z#AHSN@X0<-4^/?__\:!`"@X3;W_^LX$(WB`$"@X30&G^7<^__K``!0XW,`
M``H`D)CE`??_ZP`0H.$)`*#AM/W_ZP"04.)L```*"0"@X3GW_^L#`%#C`*"@
MX0L``)H$`$#B``")X/`5G^7,]O_K``!0XP4``!H$`%KC+0$`"@J@B>`%,%KE
M+P!3XRD!``K6_O_K`!!0X@0``!H)`*#A$/?_ZP`P4.(<,(WE50``&JP5G^6L
M!9_E#?S_ZQCW_^NDE9_E8`"-Z`R0C>6<-9_E`"#@XP$0H..4I9_E"`"-Y00`
MH.$C]__K#@``ZA[W_^L`,)#E$0!3XQ```!H(]__K`7"'X@QPC>40D(WE8`"-
MZ`@@H.$*,*#A`1"@XP@`C>4$`*#A$_?_ZP<=H.,$`*#A&??_ZP$`<.,`@*#A
MZO__"@4`H.&E]O_K!!"@X>P$G^7G^__K!`"@X<G^_^N3___J!4"@X:PPC>($
M48/@!`"5Y```4.,;```*.!"-XH;[_^L!0(3B`#!0XO?__PH`,-/E``!3X_3_
M_PJH]O_K``!0X^___PH`4*#A"?__ZJ`DG^4$,(WE`%"-Y0$0H.,``)+E`#"8
MY:PDG^4%]__K`$"@XW;__^JJ_O_K!`"@X9?V_^L`0*#A<?__Z@T`H./`]O_K
MA%2?Y5,PH.,`<*#A_?[_Z@"0F.60___J`G"@XP`PX.,1(.#C`'"-Y:GV_^ME
M'XWB!B"@XQP`G>5C]O_KE#'=Y0``4^,"```:E3'=Y4,`4^//```*`'"@XP`@
MH.,`,*#C`'"-Y1P`G>69]O_KZQ^/XM``P>'K/X_BT"##X>N?C^+0@,GA\`W-
MX?@MS>'I'X_BT`#!X>D_C^+0(,/A2'&-Y?`/S>'X+LWA`1R-X@`PH.,`(*#C
M)'"-Y?@OS>'P(,'A0C^-XO".S>$@,(WE^$+-X0(IH.-E'XWB'`"=Y3KV_^L`
MH%#B3P``VM@/S>$D4)WEBC&@X04`4>$`0(/@!`!0`0`AG>4*@*#ARI^@X001
MG>4!``":`2"2X@`0H>*H/J#AB3&#X4@!G>4",)/@J2Z@X0$@HN```%#C^$_-
MX0`QC>4$(8WE-0``"D"08.()`%KA(#"=Y0J0H+$``(/@"2"@X64?C>(G]O_K
M2#&=Y0,PB>!``%/C2#&-Y=3__QIE/XWBT`"-X@F@2N`)D(/@C_?_ZS\`6N,:
M``#:0*!*XC^`RN.`,(GB`X"(X$"PB>)`<$OB0N^-X@``E^4$$)?E"""7Y0PP
ME^4.P*#A$'"'X@L`5^$/`*SH#."@X?7__QK0`(WB0+"'XGGW_^L+`%CA[O__
M&BHSH.$!((/B`SUCX`*3B>`#HXK@"1"@X4@PH.,*(*#A(`"=Y27V_^M(H8WE
MJ___ZF6?C>+9___J'`"=Y=A"S>&6]O_K^""=Y0!QG>5"CXWBHC&@X3\P`^(!
M$(/B?P#@XS@`4>,RG[_F-W^_Y@,`R.=&``#:0"!AX@$`B.``$*#C4/;_Z]``
MC>)4]__K"`"@X3@@H.,`$*#C2O;_Z]``C>)`<8WE1)&-Y4SW_^OH$)WET#"=
MY=C`G>7@`)WE\""=Y3$?O^8S[[_F6I^-XCS/O^8P#[_F,B^_YF`1C>5F'XWB
M(SR@X53AC>5TH9_E6,&-Y5P!C>4)<*#A0X!!XF0AC>4```#J`3#8Y``PC>4'
M`*#A"C"@X0`@X.,!$*#C'?;_ZP@`6>$"<(?B]?__&E@QG^4``*#C##"-Y9`!
MS>5@`HWH`"#@XU0QG^4!$*#C!`"@X1#V_^L!___J!("8Y0``6./2_O\*"`"@
MX?OU_^L#`%#CSO[_F@0`0.(``(C@(!&?Y8_U_^L``%#C")"@`<?^_^H!`(C@
M."!AX@`0H.,)]O_KO?__ZI8QW>5!`%/C+/__&I<QW>5#`%/C*?__&I@QW>5(
M`%/C)O__&IDQW>5%`%/C(___&@!PC>4<<)WE`##@XSD@X.,'`*#AO?7_ZV4?
MC>('`*#A*2"@XW?U_^N(,)_E92^-X@@@C>4,,(WE8`"-Z(@PG^4`(.#C`1"@
MXP0`H.'<]?_KS?[_ZH_U_^L``*#A`2-%9P````")J\WO`````/[<NI@`````
M\.'2PP````!V5#(0`````$1$`0"@C0(`V$0!`.Q%`0``10$``$8!`/1%`0`@
MD`(`1$8!`)A&`0"@1@$`T$4!`$A%`0"`1P$`P$8!`-!&`0`(1@$`Y$4!`+!&
M`0"H1@$`+#.?Y?!/+>D4T$WB)%.?Y0`PD^4``)7E##"-Y?[U_^L`0*#A``"5
MY?OU_^MH,-3E"!"-XFDPP.7\`I_E-/K_ZP``4.,"```*`##0Y3$`4^.?```*
MW?S_ZP``E>7N]?_K"S"@XP$@H./0$I_EA/7_ZP``4.,O```*Q'*?Y1`0D.4`
ML)7E!""7Y1B0D>4!`%+C*@``V@!`H..HHI_E"0``ZA`0D>4(`*#A&_7_ZP0@
ME^4``%#C;@``&@)`A.("`%3A!D"@X6H``*H+`*#ATO7_ZP0@H.$`,*#C"1"@
MX:WU_^L`(%#B8```"@`0DN4(`)?E`6"$X@@PD>4&@9#G"C`#X`$+4^,`L)7E
MY/__"@L`H.$$((WEP/7_ZP0@G>4",*#C`!"2Y0`@H.,]]?_K`+"5Y0`0H.':
M___J`+"5Y0!RG^4+`*#AM/7_ZP,PH.,!(*#C]!&?Y4KU_^L`0%#B"@``"@``
ME>6L]?_K$#"4Y=PAG^4`$)/E(?7_ZQ`PE.4`,)/E"#"3Y0$%$^-<```:``"5
MY:'U_^L#,*#C`2"@X[`1G^4W]?_K`$!0X@H```H($(WBH`&?Y=;Y_^L`8%#B
M``"5Y4<```J4]?_K$#"4Y08@H.$`$)/E"?7_ZP``E>6.]?_K`$"@X0``E>6+
M]?_K`2"@XV01G^4W]?_K8"&?Y0`0H.$$`*#A_?3_ZP``E>6"]?_K`#"@XP@0
MC>)I,,#E0`&?Y;OY_^L``%#C`$"@X0P`A^4?```*!QV@XP0`H.$T]?_K`3"`
MXA$`4.,!`%,3,@``BMPPG^4,()WE`#"3Y0,`4N$L```:%-"-XO"/O>@$()?E
M`+"5Y0$00N($`%'AK___&@$`4N.M___:`4"@XPL`H.%A]?_K"1"@X;'T_^L$
M,)?E`4"$X@0`4^$`L)7E]O__RJ+__^H(`)?E`?W_ZP``4.,`0*#A#`"'Y=G_
M_QJ4`)_E"?7_ZP$PT.4``%/C7?__"EO__^I,]?_K$""4Y0@PE^4``)+E`!"3
MY='Z_^NU___J``"5Y43U_^L0,)3E`!"3Y0OU_^N<___JJ?3_ZP@0E^4`,*#A
M!""@X0`0D>4X`)_E\?3_ZZ"-`@`8D`(`+$4!`.1&`0`HD`(```0@`.Q&`0#P
M1@$`^$8!`.1$`0#\1@$`%$<!`-A$`0`<1P$`0$<!`'!`+>D`4*#AS_O_ZP`P
MT.4`0*#A``!3XP4```H!((#B+P!3XP)`H`$!,-+D``!3X_K__QIO_/_K``!5
MXP``4!-P@+T(`##5Y0``4^-P@+T(!`"@X00@H.,4$)_E`_7_ZP``4.-P@+T8
M!0"@X7!`O>@E^O_J`$8!``@PG^4#,(_@`#"3Y77T_^IH3`$`\$<MZ0!PH.%(
M8)_E2%"?Y09@C^`%4(_@!6!&X`&`H.$"D*#A,O3_ZT9AL.'PA[T(`$"@XP%`
MA.($,)7D"2"@X0@0H.$'`*#A,_\OX00`5N'W__\:\(>]Z.!)`0#820$`'O\O
MX0A`+>D(@+WH`0`"`'!E<FQX<VDN8P```%]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@`````*Q'`0!T1`$``````)1%`0"810$`H$<!`-Q$`0"H
M1P$``````(Q'`0"41P$``````"X````N+@``)7,O)7,````O<')O8R]S96QF
M+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ
M4$%2.CI"3T]4`````"]P<F]C+R5I+R5S`&5X90!005)?5$5-4`````!005)?
M4%)/1TY!344`````.@```"5S)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,
M24(`4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-0
M05=.140`4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%2
M7T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$
M25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````%!!4E]#
M3$5!3CT``#$```!,1%],24)205)97U!!5$@`4UE35$5-```E,#)X`````"5S
M)7,E<R5S`````'!A<BT`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A
M;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``4$%42`````!P87)L`````"YP
M87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M
M<"TE=2TE=25S`````$%21U8`````&````'!E<FP`````,````%!!4CHZ4&%C
M:V5R.CI615)324].`````#$N,#0W````56YA8FQE('1O(&-R96%T92!C86-H
M92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M90``+2T`
M`%5315(`````55-%4DY!344`````5$5-4$1)4@!435``+W1M<`````!E=F%L
M("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@
M(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?
M<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@
M>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM
M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP
M*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&
M:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U
M;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@
M)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE
M=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G
M+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*
M>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E
M;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS
M;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I
M;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@
M)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<[
M"F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A
M8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP
M+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/
M3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"![
M"E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH
M/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@
M("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD[
M"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T
M7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U
M8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO
M9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY
M("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F
M9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD
M;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE
M(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*
M9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S
M("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!
M4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I
M>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL
M87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E
M96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@
M7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&
M2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R
M97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE
M("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA
M;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z
M<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B
M)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA
M;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]
M("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B
M+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*
M96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y
M.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C
M(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D
M8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D
M=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4[
M"FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]
M('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T
M*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA
M<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D
M:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D
M9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E
M9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN
M97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H
M("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F
M:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA
M;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H
M+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE
M.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S
M=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@
M0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ
M1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I
M<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I
M;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC
M/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N
M86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\[
M"GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@
M=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L
M92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?
M4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P
M<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF
M("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G
M("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?
M<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG
M;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP
M72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2
M155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B
M96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'
M5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII
M9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@
M)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD
M;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@
M)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L
M<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@
M)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H
M;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]4
M14U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@
M0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I
M;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`
M05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG
M+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO
M9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A
M9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II
M<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@
M>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O
M;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A
M;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L
M("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D
M<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P
M,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z
M.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R
M(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O
M<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D
M;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS
M;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT
M.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA
M9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T
M(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[
M)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D
M,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R
M*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC
M*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$
M4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL
M97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@
M=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI
M8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE
M<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC
M*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2![
M"B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;
M7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T
M.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII
M9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M
M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D
M,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD
M(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A
M;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L
M"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D
M9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I
M*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)
M3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2([
M"F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%
M.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT
M+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@
M+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S
M*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD[
M"B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F
M:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E
M;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP
M.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF
M("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY
M72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I
M9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S
M:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF
M("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G
M-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*
M?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@
M>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H
M*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z
M("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H
M("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP
M<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^
M=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP
M;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*
M>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA
M;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@
M;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@
M(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?
M1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]4
M14U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U
M;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H
M("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O
M<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT
M('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N
M9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D
M,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM0
M05)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F
M)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S
M*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X
M=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M
M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H
M,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU
M;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N
M(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED
M:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*
M)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS
M=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL
M93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U
M:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL
M97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B
M(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,
M;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I
M<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U
M:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*
M<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD
M;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6([
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@
M?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A
M;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"
M=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R
M92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS
M8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A
M<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N
M.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%2
M7U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N
M9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W
M=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D
M("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U
M<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D
M("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R
M;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%
M32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D
M<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA
M;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!
M3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P
M96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R
M.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#
M2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T
M,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN
M97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-
M1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ
M4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS
M."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE
M*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X
M(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F
M:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T
M>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E
M('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7([
M"FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q
M(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D
M;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92([
M"G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L
M;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE
M(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R
M:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T
M96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D
M9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L
M;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK
M*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@
M*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%2
M7U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L
M(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II
M9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@
M)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O
M9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?
M97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D
M0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X
M:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0
M?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E
M>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD
M,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA
M;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]
M("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD
M969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P
M=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1
M)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E
M;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E
M='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF
M;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!
M344@05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*
M?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[
M)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S
M("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!
M4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A
M97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@
M<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.
M5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<
M4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L
M;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B
M0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S
M:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]
M+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L
M:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E
M(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD
M7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@
M0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F
M:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D
M<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`
M(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%
M4E)/4CL*,3L*7U]%3D1?7PH`");_?P$`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#<&@$`M!H!````````````````````
M```````````````````!`````0````$```#+`0```0```-8!```!````X`$`
M``$````O`@```0```'D#```!````GP,```P```"8%`$`#0````A$`0`9````
MF(T"`!L````$````&@```)R-`@`<````!````/7^_V^T`0$`!0```!0,`0`&
M````9`4!``H````#!0``"P```!`````5``````````,```#DC@(``@```!`"
M```4````$0```!<```"($@$`$0```%`2`0`2````.````!,````(````'@``
M``@```#[__]O`0```/[__V_P$0$`____;P,```#P__]O&!$!````````````
M`````````````````````````````````````````````````````+R-`@``
M`````````*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04
M`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!
M`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`
MI!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D
M%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04
M`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!
M``````````````````````#_____M$<!`$=#0SH@*%)A<W!B:6%N(#@N,BXP
M+3DK<G!I,2D@."XR+C``1T-#.B`H4F%S<&)I86X@-RXS+C`M,3DI(#<N,RXP
M`$$N````865A8FD``20````%-@`&!@@!"0$*`A($$P$4`14!%P,8`1D!&@(<
M`2(!`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU
M+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S
M:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT
M97AT`"YF:6YI`"YR;V1A=&$`+D%232YE>&ED>``N96A?9G)A;64`+FEN:71?
M87)R87D`+F9I;FE?87)R87D`+F1A=&$N<F5L+G)O`"YD>6YA;6EC`"YG;W0`
M+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T97,`````````````
M```````````````````````````````````````````+`````0````(```!4
M`0$`5`$``!D```````````````$`````````$P````<````"````<`$!`'`!
M```@```````````````$`````````"$````'`````@```)`!`0"0`0``)```
M````````````!``````````T````]O__;P(```"T`0$`M`$``+`#```%````
M``````0````$````/@````L````"````9`4!`&0%``"P!@``!@````$````$
M````$````$8````#`````@```!0,`0`4#````P4``````````````0``````
M``!.````____;P(````8$0$`&!$``-8````%``````````(````"````6P``
M`/[__V\"````\!$!`/`1``!@````!@````,````$`````````&H````)````
M`@```%`2`0!0$@``.`````4`````````!`````@```!S````"0```$(```"(
M$@$`B!(``!`"```%````%@````0````(````?`````$````&````F!0!`)@4
M```,```````````````$`````````'<````!````!@```*04`0"D%```+`,`
M````````````!`````0```""`````0````8```#0%P$`T!<``#@L````````
M``````@`````````B`````$````&````"$0!``A$```(```````````````$
M`````````(X````!`````@```!!$`0`01```V#\`````````````!```````
M``"6`````0``<((```#H@P$`Z(,```@````-``````````0`````````H0``
M``$````"````\(,!`/"#```$```````````````$`````````*L````.````
M`P```)B-`@"8C0``!```````````````!`````0```"W````#P````,```"<
MC0(`G(T```0```````````````0````$````PP````$````#````H(T"`*"-
M```;```````````````(`````````-`````&`````P```+R-`@"\C0``*`$`
M``8`````````!`````@```#9`````0````,```#DC@(`Y(X``!@!````````
M``````0````$````W@````$````#`````)`"``"0```0```````````````$
M`````````.0````(`````P```!"0`@`0D```+!``````````````"```````
M``#I`````0```#``````````$)```$(```````````````$````!````\@``
M``,``'```````````%*0```O```````````````!``````````$````#````
@``````````"!D````@$``````````````0``````````
